#!/bin/sh

# Copyright (C) 2019, 2020 Svante Signell

# Written by Svante Signell  <svante.signell@gmail.com>

# This file is part of hurd-cross.

# Hurd-cross is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published
# by the Free Software Foundation; either version 3 or (at your
# option) any later version.

# Hurd-cross is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with hurd-cross.  If not, see <http://www.gnu.org/licenses/>.

. ./package-versions.sh
. ./environment-variables.sh

echo ""
echo "File: bootstrap-funcs.sh"

# You can change the GCC version here.
#export CC="$HOST_MACHINE"-gcc
#export CXX="$HOST_MACHINE"-g++
#export AR="$HOST_MACHINE-ar"
#export AS="$HOST_MACHINE-as"

compile_binutils ()
{
   rm -rf "$BINUTILS_SRC".obj
   mkdir -p "$BINUTILS_SRC".obj
   cd "$BINUTILS_SRC".obj
   ../$BINUTILS_SRC/configure \
     --build="$HOST" \
     --host="$HOST" \
     --target="$TARGET" \
     --prefix="$CROSS_ROOT" \
     --enable-static \
     --disable-multilib \
     --disable-werror \
     --disable-nls
   make -j$PROCS all
   fakeroot make install
   cd ..
   rm -rf "$BINUTILS_SRC".obj
}

install_gnumach_headers() {
   print_info "Installing GNU Mach Headers"
   cd "$GNUMACH_SRC"
   autoreconf -i
   cd ..
   rm -rf "$GNUMACH_SRC".obj
   mkdir -p "$GNUMACH_SRC".obj
   cd "$GNUMACH_SRC".obj
   ../$GNUMACH_SRC/configure \
     --build="$HOST" \
     --host="$TARGET" \
     --prefix="$CROSS_ROOT"
   make -j$PROCS install-data
   cd -
   rm -rf "$GNUMACH_SRC".obj
}

install_hurd_headers() {
   print_info "Installing Hurd headers"
   apply_patch $SCRIPT_DIR/patches/hurd/configure.ac.diff 1
   cd "$HURD_SRC"
   autoreconf -i
   cd ..
   rm -rf "$HURD_SRC".obj
   mkdir -p "$HURD_SRC".obj
   cd "$HURD_SRC".obj
   ../$HURD_SRC/configure \
     --build="$HOST" \
     --host="$TARGET" \
     --prefix="$CROSS_ROOT" \
     --disable-profile \
     --without-parted
   fakeroot make -j$PROCS install-headers no_deps=t
   cd ..
   unapply_patch $SCRIPT_DIR/patches/hurd/configure.ac.diff 1
   rm -rf "$HURD_SRC".obj
}

compile_first_gcc ()
{
   print_info "Cross-compiling first phase of GCC"
   cd "$GCC_SRC"
   autoreconf -i
   cd ..
   rm -rf "$GCC_SRC".obj
   mkdir -p "$GCC_SRC".obj
   cd "$GCC_SRC".obj
   LDFLAGS="-Wl,-rpath,${CROSS_ROOT}/lib" \
   ../$GCC_SRC/configure \
     --build="$HOST" \
     --host="$HOST" \
     --target="$TARGET" \
     --prefix="$CROSS_ROOT" \
     --enable-languages=c \
     --disable-bootstrap \
     --disable-shared \
     --disable-threads \
     --disable-libatomic \
     --enable-decimal-float \
     --disable-libffi \
     --disable-libgomp \
     --disable-libitm \
     --disable-libmpx \
     --disable-libquadmath \
     --without-headers \
     --with-newlib \
     --disable-nls \
     --disable-threads \
     --disable-multilib \
     --disable-target-zlib \
     --with-system-zlib \
     --disable-libssp \
     --disable-libvtv \
     --disable-libstdcxx
   make -j$PROCS all-gcc
   fakeroot make install-gcc
   make -j$PROCS configure-target-libgcc
   cd "$TARGET"/libgcc
   make -j$PROCS all
   fakeroot make install
   cd ../..
#   cd "$GCC_SRC"
   cd ..
   rm -rf "$GCC_SRC".obj
}

install_gnumig() {
   print_info "Cross-compiling GNU Mig"
   cd "$GNUMIG_SRC"
   autoreconf -i
   cd ..
   rm -rf "$GNUMIG_SRC".obj
   mkdir -p "$GNUMIG_SRC".obj
   cd "$GNUMIG_SRC".obj
   ../$GNUMIG_SRC/configure \
     --build="$HOST" \
     --target="$TARGET" \
     --prefix="$CROSS_ROOT"
   make -j$PROCS
   fakeroot make install
   cd ..
   rm -rf "$GNUMIG_SRC".obj
}

compile_first_glibc() {
   print_info "Cross-compiling first stage of glibc"
   cd "$GLIBC_SRC"
   autoreconf -i
   cd ..
   rm -rf "$GLIBC_SRC".obj
   mkdir -p "$GLIBC_SRC".obj
   cd "$GLIBC_SRC".obj
   ../$GLIBC_SRC/configure \
      --with-binutils=${ROOT}/bin \
      --build="$HOST" \
      --host="$TARGET" \
      --prefix="$CROSS_ROOT" \
      --cache-file=config.cache \
      --enable-shared \
      --disable-static \
      --disable-mathvec \
      --disable-profile \
      --enable-obsolete-rpc \
      --disable-werror \
      --disable-nscd
   make -j$PROCS
   fakeroot make install
   cd ..
   rm -rf "$GLIBC_SRC".obj
}

#fixinc_glimits.h.diff
compile_full_gcc () {
   print_info "Cross-compiling full GCC"
   cd "$GCC_SRC"
   apply_patch $SCRIPT_DIR/patches/gcc/fixinc_glimits.h.diff 1
   autoreconf -i
   cd ..
   rm -rf "$GCC_SRC".obj
   mkdir -p "$GCC_SRC".obj
   cd "$GCC_SRC".obj
   ../$GCC_SRC/configure \
     --target="$TARGET" \
     --prefix="$CROSS_ROOT" \
     --disable-static \
     --disable-nls \
     --enable-languages=c,c++ \
     --enable-threads=posix \
     --disable-multilib \
     --with-system-zlib \
     --with-libstdcxx-time \
     --disable-libstdcxx-pch \
     --disable-bootstrap \
     --disable-libcilkrts \
     --disable-libgomp \
     --disable-multi-arch \
     --with-arch=$CPU
   make -j$PROCS all
   fakeroot make install
   cd ..
   cd $GCC_SRC
   unapply_patch $SCRIPT_DIR/patches/gcc/fixinc_glimits.h.diff 1
   cd ..
   rm -rf "$GCC_SRC".obj
}

compile_full_glibc() {
   print_info "Cross-compiling full glibc"
   rm -rf "$GLIBC_SRC".obj
   mkdir -p "$GLIBC_SRC".obj
   cd "$GLIBC_SRC".obj
   rm -f config.cache
   ../$GLIBC_SRC/configure \
      --with-binutils=${ROOT}/bin \
      --build="$HOST" \
      --host="$TARGET" \
      --prefix="$CROSS_ROOT" \
      --enable-obsolete-rpc \
      --disable-profile \
      --enable-obsolete-rpc \
      --disable-werror \
      --disable-nscd
   make -j$PROCS
   fakeroot make install
   cd ..
   rm -rf "$GLIBC_SRC".obj
}
